ShardModel class

Constructors

ShardModel()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getApiKey() Future<String>
getSenderId() Future<String>
getToken() Future<String>
getUserId() Future<String>
getUserName() Future<String>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setApiKey(String x) Future<void>
setSenderId(String x) Future<void>
setToken(String x) Future<void>
setUserId(String x) Future<void>
setUserName(String x) Future<void>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited