RecordService class

Constructors

RecordService({dynamic onDurationUpdate(Duration)?})

Properties

audioPath String?
no setter
hashCode int
The hash code for this object.
no setterinherited
isRecording bool
no setter
onDurationUpdate ↔ dynamic Function(Duration)?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

dispose() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
startRecording() Future<void>
stopRecording() Future<void>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited