MessageModel class

Constructors

MessageModel({String? senderId, String? roomId, String? messageId, String? time, String? text, MediaFile? file, String? fileTime, List<String>? reacts})
MessageModel.fromJson(dynamic jsonData)
factory

Properties

file MediaFile?
getter/setter pair
fileTime String?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
messageId String?
getter/setter pair
reacts List<String>?
getter/setter pair
roomId String?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
senderId String?
getter/setter pair
text String?
getter/setter pair
time String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited