RoomsService class

Constructors

RoomsService()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

createRoom({required String type, required List<String> members, String? roomName}) Future<bool>
getRooms() Future<List<RoomModel>?>
joinRoom(String roomId) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onlineCheck(RoomModel room) → void
onlineResult({required void onlineFn(String userId, bool online)}) → void
recordCheck(String roomId, bool isRecording) → void
recordingResult({required void recordFn(String userId, bool recording)}) → void
toString() String
A string representation of this object.
inherited
typingCheck(String roomId, bool isTyping) → void
typingResult({required void typingFn(String userId, bool typing)}) → void

Operators

operator ==(Object other) bool
The equality operator.
inherited