RoomModel class
Constructors
-
RoomModel({required String roomId, String? name, String? type, LastMassage? lastMessage, List<
String> ? usersIds, List<String> ? ids}) - RoomModel.fromJson(dynamic jsonData)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
ids
→ List<
String> ? -
final
- lastMessage → LastMassage?
-
final
- name → String?
-
final
- roomId → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → String?
-
final
-
usersIds
→ List<
String> ? -
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited