MessageService class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
aiMessage(
{required String message}) → Future< String> -
downloadFiles(
{required String path}) → Future< Uint8List?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
receiveMessages(
{required void onMessageReceived(MessageModel message)}) → void -
receiveReact(
{required void onReactReceived(String messageId, String react)}) → void -
sendFiles(
{required String roomId, required Uint8List bytesFile, required String name, required String type}) → Future< MessageModel> -
sendMessage(
{required String mess, required String roomId}) → Future< MessageModel> -
sendReact(
{required String messageId, required String react}) → void -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited